solve_lower_triangular_in_place

Function solve_lower_triangular_in_place 

pub fn solve_lower_triangular_in_place<I: Index, T: ComplexField>(
    tril: SparseColMatRef<'_, I, T>,
    conj_tril: Conj,
    rhs: MatMut<'_, T>,
    par: Par,
)
assuming tril is a lower triangular matrix, solves the equation tril * x = rhs, and stores the result in rhs, implicitly conjugating tril if needed

note

the matrix indices need not be sorted, but the diagonal element is assumed to be the first stored element in each column.